==> conf4cpp-0.0.4.tar.gz: conf4cpp-0.0.4/inc/conf4cpp/config.hpp <==
/*=============================================================================
 *
 * Copyright (c) 2008- Kenta Hattori
 *
 *===========================================================================*/
#ifndef CONFIG_HPP
#define CONFIG_HPP

#include <conf4cpp/error.hpp>
#include <conf4cpp/parser.hpp>

namespace conf4cpp
{
    template <class derived_config_parser_T>
    class base_config {
    public:
	base_config(const string& fname) {
	    derived_config_parser_T g(vm_);
	    parse_config(fname, g);
	}

    protected:
	value_map_t vm_;

    private:
	void parse_config(const string& fname, const derived_config_parser_T& g) {
	    typedef file_iterator<char> file_iterator_t;

	    file_iterator_t first(fname);
	    if (!first) throw error("could not open file");
	    file_iterator_t last = first.make_end();

	    typedef position_iterator<file_iterator_t> position_iterator_t;
	    position_iterator_t begin(first, last, fname);
	    position_iterator_t end;
	    begin.set_tabchars(8);
	    try {
		parse_info<position_iterator_t> pinfo = parse(begin, end, g, eol_p|space_p|comment_p("#"));
		if (!pinfo.full) throw error("parse error", pinfo.stop.get_position().line);
	    } catch (boost::spirit::parser_error<string,position_iterator_t>& e) {
		throw error(e.descriptor, e.where.get_position().line);
	    }
	    for (unsigned int i = 0; i < g.reqs.size(); i++) {
		if (vm_.find(g.reqs[i]) == vm_.end()) throw error("item undefined", g.reqs[i]);
	    }
	}
    };
}

#endif /* CONFIG_HPP */

==> conf4cpp-0.0.5.tar.gz: conf4cpp-0.0.5/inc/conf4cpp/config.hpp <==
/*=============================================================================
 *
 * Copyright (c) 2008- Kenta Hattori
 *
 *===========================================================================*/
#ifndef CONFIG_HPP
#define CONFIG_HPP

#include <conf4cpp/error.hpp>
#include <conf4cpp/parser.hpp>

namespace conf4cpp
{
    template <class derived_config_parser_T>
    class base_config {
    public:
	base_config(const string& fname) {
	    p = new derived_config_parser_T();
	    parse_config(fname);
	}
	virtual ~base_config();
        bool set(const string& itemdef);

    protected:
        derived_config_parser_T* p;

    private:
	void parse_config(const string& fname) {
	    typedef file_iterator<char> file_iterator_t;

	    file_iterator_t first(fname);
	    if (!first) throw error("could not open file");
	    file_iterator_t last = first.make_end();

	    typedef position_iterator<file_iterator_t> position_iterator_t;
	    position_iterator_t begin(first, last, fname);
	    position_iterator_t end;
	    begin.set_tabchars(8);
	    try {
		p->init();
		parse_info<position_iterator_t> pinfo = parse(begin, end, *p, eol_p|space_p|comment_p("#"));
		if (!pinfo.full) throw error("parse error", pinfo.stop.get_position().line);
	    } catch (boost::spirit::parser_error<string,position_iterator_t>& e) {
		throw error(e.descriptor, e.where.get_position().line);
	    }
	    for (unsigned int i = 0; i < p->reqs.size(); i++) {
		if (p->vmap.find(p->reqs[i]) == p->vmap.end()) throw error("item undefined", p->reqs[i]);
	    }
	}
	bool parse_itemdef(const string& itemdef) {
	    try {
		p->init();
		parse_info<> pinfo = parse(itemdef.c_str(), *p, eol_p|space_p);
		if (!pinfo.full) return false;
	    } catch (boost::spirit::parser_error<string>& e) {
		return false;
	    }
            return true;
	}

    };
}

#endif /* CONFIG_HPP */
